# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from ZSGF.Client.models.boolean_api_response import BooleanApiResponse
from ZSGF.Client.models.currency_consume_request import CurrencyConsumeRequest
from ZSGF.Client.models.exchange_currency_request import ExchangeCurrencyRequest
from ZSGF.Client.models.recharge_point_request import RechargePointRequest
from ZSGF.Client.models.user_currency_currency_trans_result_api_response import UserCurrencyCurrencyTransResultApiResponse
from ZSGF.Client.models.user_currency_list_api_response import UserCurrencyListApiResponse

from ZSGF.Client.api_client import ApiClient, RequestSerialized
from ZSGF.Client.api_response import ApiResponse
from ZSGF.Client.rest import RESTResponseType


class UserCurrencyApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def user_currencies(
        self,
        id: Annotated[StrictInt, Field(description="用户ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserCurrencyListApiResponse:
        """获取用户资产

        根据用户ID获取用户的资产列表

        :param id: 用户ID (required)
        :type id: int
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currencies_serialize(
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserCurrencyListApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def user_currencies_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="用户ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserCurrencyListApiResponse]:
        """获取用户资产

        根据用户ID获取用户的资产列表

        :param id: 用户ID (required)
        :type id: int
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currencies_serialize(
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserCurrencyListApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def user_currencies_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="用户ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """获取用户资产

        根据用户ID获取用户的资产列表

        :param id: 用户ID (required)
        :type id: int
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currencies_serialize(
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserCurrencyListApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _user_currencies_serialize(
        self,
        id,
        app_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/UserCurrency/{appKey}/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def user_currency_consume(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        currency_consume_request: Annotated[Optional[CurrencyConsumeRequest], Field(description="消费请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BooleanApiResponse:
        """消费虚拟币

        根据提供的参数进行虚拟币消费

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param currency_consume_request: 消费请求参数
        :type currency_consume_request: CurrencyConsumeRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_consume_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            currency_consume_request=currency_consume_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def user_currency_consume_with_http_info(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        currency_consume_request: Annotated[Optional[CurrencyConsumeRequest], Field(description="消费请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BooleanApiResponse]:
        """消费虚拟币

        根据提供的参数进行虚拟币消费

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param currency_consume_request: 消费请求参数
        :type currency_consume_request: CurrencyConsumeRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_consume_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            currency_consume_request=currency_consume_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def user_currency_consume_without_preload_content(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        currency_consume_request: Annotated[Optional[CurrencyConsumeRequest], Field(description="消费请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """消费虚拟币

        根据提供的参数进行虚拟币消费

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param currency_consume_request: 消费请求参数
        :type currency_consume_request: CurrencyConsumeRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_consume_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            currency_consume_request=currency_consume_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _user_currency_consume_serialize(
        self,
        nonce,
        timestamp,
        signature,
        app_key,
        currency_consume_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if nonce is not None:
            
            _query_params.append(('nonce', nonce))
            
        if timestamp is not None:
            
            _query_params.append(('timestamp', timestamp))
            
        if signature is not None:
            
            _query_params.append(('signature', signature))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if currency_consume_request is not None:
            _body_params = currency_consume_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json-patch+json', 
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/UserCurrency/{appKey}/CurrencyConsume',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def user_currency_exchange(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        exchange_currency_request: Annotated[Optional[ExchangeCurrencyRequest], Field(description="兑换请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BooleanApiResponse:
        """兑换虚拟币

        根据提供的参数进行虚拟币兑换

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param exchange_currency_request: 兑换请求参数
        :type exchange_currency_request: ExchangeCurrencyRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_exchange_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            exchange_currency_request=exchange_currency_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def user_currency_exchange_with_http_info(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        exchange_currency_request: Annotated[Optional[ExchangeCurrencyRequest], Field(description="兑换请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BooleanApiResponse]:
        """兑换虚拟币

        根据提供的参数进行虚拟币兑换

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param exchange_currency_request: 兑换请求参数
        :type exchange_currency_request: ExchangeCurrencyRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_exchange_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            exchange_currency_request=exchange_currency_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def user_currency_exchange_without_preload_content(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        exchange_currency_request: Annotated[Optional[ExchangeCurrencyRequest], Field(description="兑换请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """兑换虚拟币

        根据提供的参数进行虚拟币兑换

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param exchange_currency_request: 兑换请求参数
        :type exchange_currency_request: ExchangeCurrencyRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_exchange_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            exchange_currency_request=exchange_currency_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _user_currency_exchange_serialize(
        self,
        nonce,
        timestamp,
        signature,
        app_key,
        exchange_currency_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if nonce is not None:
            
            _query_params.append(('nonce', nonce))
            
        if timestamp is not None:
            
            _query_params.append(('timestamp', timestamp))
            
        if signature is not None:
            
            _query_params.append(('signature', signature))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if exchange_currency_request is not None:
            _body_params = exchange_currency_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json-patch+json', 
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/UserCurrency/{appKey}/CurrencyExchange',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def user_currency_recharge(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        recharge_point_request: Annotated[Optional[RechargePointRequest], Field(description="充值请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BooleanApiResponse:
        """充值虚拟币

        根据提供的参数进行虚拟币充值

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param recharge_point_request: 充值请求参数
        :type recharge_point_request: RechargePointRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_recharge_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            recharge_point_request=recharge_point_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def user_currency_recharge_with_http_info(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        recharge_point_request: Annotated[Optional[RechargePointRequest], Field(description="充值请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BooleanApiResponse]:
        """充值虚拟币

        根据提供的参数进行虚拟币充值

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param recharge_point_request: 充值请求参数
        :type recharge_point_request: RechargePointRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_recharge_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            recharge_point_request=recharge_point_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def user_currency_recharge_without_preload_content(
        self,
        nonce: Annotated[StrictStr, Field(description="随机数")],
        timestamp: Annotated[StrictInt, Field(description="时间戳（允许与服务器时间误差在1分钟内）")],
        signature: Annotated[StrictStr, Field(description="签名")],
        app_key: StrictStr,
        recharge_point_request: Annotated[Optional[RechargePointRequest], Field(description="充值请求参数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """充值虚拟币

        根据提供的参数进行虚拟币充值

        :param nonce: 随机数 (required)
        :type nonce: str
        :param timestamp: 时间戳（允许与服务器时间误差在1分钟内） (required)
        :type timestamp: int
        :param signature: 签名 (required)
        :type signature: str
        :param app_key: (required)
        :type app_key: str
        :param recharge_point_request: 充值请求参数
        :type recharge_point_request: RechargePointRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_recharge_serialize(
            nonce=nonce,
            timestamp=timestamp,
            signature=signature,
            app_key=app_key,
            recharge_point_request=recharge_point_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _user_currency_recharge_serialize(
        self,
        nonce,
        timestamp,
        signature,
        app_key,
        recharge_point_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if nonce is not None:
            
            _query_params.append(('nonce', nonce))
            
        if timestamp is not None:
            
            _query_params.append(('timestamp', timestamp))
            
        if signature is not None:
            
            _query_params.append(('signature', signature))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if recharge_point_request is not None:
            _body_params = recharge_point_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json-patch+json', 
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/UserCurrency/{appKey}/CurrencyRecharge',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def user_currency_transactions(
        self,
        app_key: StrictStr,
        trans_type: Annotated[Optional[StrictStr], Field(description="交易类型")] = None,
        cur_code: Annotated[Optional[StrictStr], Field(description="货币代码")] = None,
        start_time: Annotated[Optional[datetime], Field(description="开始时间")] = None,
        end_time: Annotated[Optional[datetime], Field(description="结束时间")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="跳过的条数")] = None,
        take: Annotated[Optional[StrictInt], Field(description="拉取的条数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserCurrencyCurrencyTransResultApiResponse:
        """虚拟币交易记录

        根据提供的参数获取虚拟币交易记录

        :param app_key: (required)
        :type app_key: str
        :param trans_type: 交易类型
        :type trans_type: str
        :param cur_code: 货币代码
        :type cur_code: str
        :param start_time: 开始时间
        :type start_time: datetime
        :param end_time: 结束时间
        :type end_time: datetime
        :param skip: 跳过的条数
        :type skip: int
        :param take: 拉取的条数
        :type take: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_transactions_serialize(
            app_key=app_key,
            trans_type=trans_type,
            cur_code=cur_code,
            start_time=start_time,
            end_time=end_time,
            skip=skip,
            take=take,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserCurrencyCurrencyTransResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def user_currency_transactions_with_http_info(
        self,
        app_key: StrictStr,
        trans_type: Annotated[Optional[StrictStr], Field(description="交易类型")] = None,
        cur_code: Annotated[Optional[StrictStr], Field(description="货币代码")] = None,
        start_time: Annotated[Optional[datetime], Field(description="开始时间")] = None,
        end_time: Annotated[Optional[datetime], Field(description="结束时间")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="跳过的条数")] = None,
        take: Annotated[Optional[StrictInt], Field(description="拉取的条数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserCurrencyCurrencyTransResultApiResponse]:
        """虚拟币交易记录

        根据提供的参数获取虚拟币交易记录

        :param app_key: (required)
        :type app_key: str
        :param trans_type: 交易类型
        :type trans_type: str
        :param cur_code: 货币代码
        :type cur_code: str
        :param start_time: 开始时间
        :type start_time: datetime
        :param end_time: 结束时间
        :type end_time: datetime
        :param skip: 跳过的条数
        :type skip: int
        :param take: 拉取的条数
        :type take: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_transactions_serialize(
            app_key=app_key,
            trans_type=trans_type,
            cur_code=cur_code,
            start_time=start_time,
            end_time=end_time,
            skip=skip,
            take=take,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserCurrencyCurrencyTransResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def user_currency_transactions_without_preload_content(
        self,
        app_key: StrictStr,
        trans_type: Annotated[Optional[StrictStr], Field(description="交易类型")] = None,
        cur_code: Annotated[Optional[StrictStr], Field(description="货币代码")] = None,
        start_time: Annotated[Optional[datetime], Field(description="开始时间")] = None,
        end_time: Annotated[Optional[datetime], Field(description="结束时间")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="跳过的条数")] = None,
        take: Annotated[Optional[StrictInt], Field(description="拉取的条数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """虚拟币交易记录

        根据提供的参数获取虚拟币交易记录

        :param app_key: (required)
        :type app_key: str
        :param trans_type: 交易类型
        :type trans_type: str
        :param cur_code: 货币代码
        :type cur_code: str
        :param start_time: 开始时间
        :type start_time: datetime
        :param end_time: 结束时间
        :type end_time: datetime
        :param skip: 跳过的条数
        :type skip: int
        :param take: 拉取的条数
        :type take: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._user_currency_transactions_serialize(
            app_key=app_key,
            trans_type=trans_type,
            cur_code=cur_code,
            start_time=start_time,
            end_time=end_time,
            skip=skip,
            take=take,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserCurrencyCurrencyTransResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _user_currency_transactions_serialize(
        self,
        app_key,
        trans_type,
        cur_code,
        start_time,
        end_time,
        skip,
        take,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if trans_type is not None:
            
            _query_params.append(('transType', trans_type))
            
        if cur_code is not None:
            
            _query_params.append(('curCode', cur_code))
            
        if start_time is not None:
            if isinstance(start_time, datetime):
                _query_params.append(
                    (
                        'startTime',
                        start_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('startTime', start_time))
            
        if end_time is not None:
            if isinstance(end_time, datetime):
                _query_params.append(
                    (
                        'endTime',
                        end_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('endTime', end_time))
            
        if skip is not None:
            
            _query_params.append(('skip', skip))
            
        if take is not None:
            
            _query_params.append(('take', take))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/UserCurrency/{appKey}/CurrencyTransactions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ZSGF.Client.models.sub_fee import SubFee
from typing import Optional, Set
from typing_extensions import Self

class ChargeInfo(BaseModel):
    """
    ChargeInfo
    """ # noqa: E501
    charge_fee: Optional[StrictStr] = Field(default=None, alias="chargeFee")
    charge_type: Optional[StrictStr] = Field(default=None, alias="chargeType")
    is_rating_on_switch: Optional[StrictStr] = Field(default=None, alias="isRatingOnSwitch")
    is_rating_on_trade_receiver: Optional[StrictStr] = Field(default=None, alias="isRatingOnTradeReceiver")
    original_charge_fee: Optional[StrictStr] = Field(default=None, alias="originalChargeFee")
    sub_fee_detail_list: Optional[List[SubFee]] = Field(default=None, alias="subFeeDetailList")
    switch_fee_rate: Optional[StrictStr] = Field(default=None, alias="switchFeeRate")
    __properties: ClassVar[List[str]] = ["chargeFee", "chargeType", "isRatingOnSwitch", "isRatingOnTradeReceiver", "originalChargeFee", "subFeeDetailList", "switchFeeRate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChargeInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in sub_fee_detail_list (list)
        _items = []
        if self.sub_fee_detail_list:
            for _item_sub_fee_detail_list in self.sub_fee_detail_list:
                if _item_sub_fee_detail_list:
                    _items.append(_item_sub_fee_detail_list.to_dict())
            _dict['subFeeDetailList'] = _items
        # set to None if charge_fee (nullable) is None
        # and model_fields_set contains the field
        if self.charge_fee is None and "charge_fee" in self.model_fields_set:
            _dict['chargeFee'] = None

        # set to None if charge_type (nullable) is None
        # and model_fields_set contains the field
        if self.charge_type is None and "charge_type" in self.model_fields_set:
            _dict['chargeType'] = None

        # set to None if is_rating_on_switch (nullable) is None
        # and model_fields_set contains the field
        if self.is_rating_on_switch is None and "is_rating_on_switch" in self.model_fields_set:
            _dict['isRatingOnSwitch'] = None

        # set to None if is_rating_on_trade_receiver (nullable) is None
        # and model_fields_set contains the field
        if self.is_rating_on_trade_receiver is None and "is_rating_on_trade_receiver" in self.model_fields_set:
            _dict['isRatingOnTradeReceiver'] = None

        # set to None if original_charge_fee (nullable) is None
        # and model_fields_set contains the field
        if self.original_charge_fee is None and "original_charge_fee" in self.model_fields_set:
            _dict['originalChargeFee'] = None

        # set to None if sub_fee_detail_list (nullable) is None
        # and model_fields_set contains the field
        if self.sub_fee_detail_list is None and "sub_fee_detail_list" in self.model_fields_set:
            _dict['subFeeDetailList'] = None

        # set to None if switch_fee_rate (nullable) is None
        # and model_fields_set contains the field
        if self.switch_fee_rate is None and "switch_fee_rate" in self.model_fields_set:
            _dict['switchFeeRate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChargeInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "chargeFee": obj.get("chargeFee"),
            "chargeType": obj.get("chargeType"),
            "isRatingOnSwitch": obj.get("isRatingOnSwitch"),
            "isRatingOnTradeReceiver": obj.get("isRatingOnTradeReceiver"),
            "originalChargeFee": obj.get("originalChargeFee"),
            "subFeeDetailList": [SubFee.from_dict(_item) for _item in obj["subFeeDetailList"]] if obj.get("subFeeDetailList") is not None else None,
            "switchFeeRate": obj.get("switchFeeRate")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class UserAccessToken(BaseModel):
    """
    用户令牌实体，用于管理用户的访问令牌及其相关信息。
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="用户令牌的唯一标识符。")
    user_id: Optional[StrictInt] = Field(default=None, description="与令牌关联的用户ID。", alias="userID")
    enable: Optional[StrictBool] = Field(default=None, description="指示令牌是否处于启用状态。")
    permissions: Optional[StrictStr] = Field(default=None, description="令牌拥有的权限列表，多个权限以逗号分隔。")
    title: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="令牌的标题或名称，用于标识令牌。")
    access_token: Optional[StrictStr] = Field(default=None, description="访问令牌的具体值，用于身份验证。", alias="accessToken")
    tags: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="用于分类或标记令牌的标签。")
    description: Optional[StrictStr] = Field(default=None, description="令牌的详细描述信息。")
    expire_time: Optional[datetime] = Field(default=None, description="令牌的过期时间，超过该时间令牌将失效。", alias="expireTime")
    create_date: Optional[datetime] = Field(default=None, description="令牌的创建日期，默认为当前时间。", alias="createDate")
    last_update: Optional[datetime] = Field(default=None, description="令牌的最后更新日期，默认为当前时间。", alias="lastUpdate")
    __properties: ClassVar[List[str]] = ["id", "userID", "enable", "permissions", "title", "accessToken", "tags", "description", "expireTime", "createDate", "lastUpdate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserAccessToken from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if permissions (nullable) is None
        # and model_fields_set contains the field
        if self.permissions is None and "permissions" in self.model_fields_set:
            _dict['permissions'] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict['title'] = None

        # set to None if access_token (nullable) is None
        # and model_fields_set contains the field
        if self.access_token is None and "access_token" in self.model_fields_set:
            _dict['accessToken'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserAccessToken from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "userID": obj.get("userID"),
            "enable": obj.get("enable"),
            "permissions": obj.get("permissions"),
            "title": obj.get("title"),
            "accessToken": obj.get("accessToken"),
            "tags": obj.get("tags"),
            "description": obj.get("description"),
            "expireTime": obj.get("expireTime"),
            "createDate": obj.get("createDate"),
            "lastUpdate": obj.get("lastUpdate")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ZSGF.Client.models.bk_agent_resp_info import BkAgentRespInfo
from ZSGF.Client.models.charge_info import ChargeInfo
from ZSGF.Client.models.enterprise_pay_info import EnterprisePayInfo
from ZSGF.Client.models.fulfillment_detail import FulfillmentDetail
from ZSGF.Client.models.goods_detail import GoodsDetail
from ZSGF.Client.models.hb_fq_pay_info import HbFqPayInfo
from ZSGF.Client.models.intact_charge_info import IntactChargeInfo
from ZSGF.Client.models.payment_info_with_id import PaymentInfoWithId
from ZSGF.Client.models.tap_pay_info import TapPayInfo
from ZSGF.Client.models.trade_fund_bill import TradeFundBill
from ZSGF.Client.models.trade_settle_info import TradeSettleInfo
from ZSGF.Client.models.voucher_detail import VoucherDetail
from typing import Optional, Set
from typing_extensions import Self

class AlipayTradeQueryResponse(BaseModel):
    """
    AlipayTradeQueryResponse
    """ # noqa: E501
    code: Optional[StrictStr] = None
    msg: Optional[StrictStr] = None
    sub_code: Optional[StrictStr] = Field(default=None, alias="subCode")
    sub_msg: Optional[StrictStr] = Field(default=None, alias="subMsg")
    is_error: Optional[StrictBool] = Field(default=None, alias="isError")
    additional_status: Optional[StrictStr] = Field(default=None, alias="additionalStatus")
    alipay_store_id: Optional[StrictStr] = Field(default=None, alias="alipayStoreId")
    alipay_sub_merchant_id: Optional[StrictStr] = Field(default=None, alias="alipaySubMerchantId")
    async_pay_apply_status: Optional[StrictStr] = Field(default=None, alias="asyncPayApplyStatus")
    auth_trade_pay_mode: Optional[StrictStr] = Field(default=None, alias="authTradePayMode")
    biz_settle_mode: Optional[StrictStr] = Field(default=None, alias="bizSettleMode")
    bkagent_resp_info: Optional[BkAgentRespInfo] = Field(default=None, alias="bkagentRespInfo")
    body: Optional[StrictStr] = None
    buyer_logon_id: Optional[StrictStr] = Field(default=None, alias="buyerLogonId")
    buyer_open_id: Optional[StrictStr] = Field(default=None, alias="buyerOpenId")
    buyer_pay_amount: Optional[StrictStr] = Field(default=None, alias="buyerPayAmount")
    buyer_user_id: Optional[StrictStr] = Field(default=None, alias="buyerUserId")
    buyer_user_name: Optional[StrictStr] = Field(default=None, alias="buyerUserName")
    buyer_user_type: Optional[StrictStr] = Field(default=None, alias="buyerUserType")
    cashier_type: Optional[StrictStr] = Field(default=None, alias="cashierType")
    charge_amount: Optional[StrictStr] = Field(default=None, alias="chargeAmount")
    charge_flags: Optional[StrictStr] = Field(default=None, alias="chargeFlags")
    charge_info_list: Optional[List[ChargeInfo]] = Field(default=None, alias="chargeInfoList")
    credit_biz_order_id: Optional[StrictStr] = Field(default=None, alias="creditBizOrderId")
    credit_pay_mode: Optional[StrictStr] = Field(default=None, alias="creditPayMode")
    discount_amount: Optional[StrictStr] = Field(default=None, alias="discountAmount")
    discount_goods_detail: Optional[StrictStr] = Field(default=None, alias="discountGoodsDetail")
    enterprise_pay_info: Optional[EnterprisePayInfo] = Field(default=None, alias="enterprisePayInfo")
    ext_infos: Optional[StrictStr] = Field(default=None, alias="extInfos")
    fulfillment_detail_list: Optional[List[FulfillmentDetail]] = Field(default=None, alias="fulfillmentDetailList")
    fund_bill_list: Optional[List[TradeFundBill]] = Field(default=None, alias="fundBillList")
    hb_fq_pay_info: Optional[HbFqPayInfo] = Field(default=None, alias="hbFqPayInfo")
    hyb_amount: Optional[StrictStr] = Field(default=None, alias="hybAmount")
    industry_sepc_detail: Optional[StrictStr] = Field(default=None, alias="industrySepcDetail")
    industry_sepc_detail_acc: Optional[StrictStr] = Field(default=None, alias="industrySepcDetailAcc")
    industry_sepc_detail_gov: Optional[StrictStr] = Field(default=None, alias="industrySepcDetailGov")
    intact_charge_info_list: Optional[List[IntactChargeInfo]] = Field(default=None, alias="intactChargeInfoList")
    invoice_amount: Optional[StrictStr] = Field(default=None, alias="invoiceAmount")
    mdiscount_amount: Optional[StrictStr] = Field(default=None, alias="mdiscountAmount")
    medical_insurance_info: Optional[StrictStr] = Field(default=None, alias="medicalInsuranceInfo")
    open_id: Optional[StrictStr] = Field(default=None, alias="openId")
    out_trade_no: Optional[StrictStr] = Field(default=None, alias="outTradeNo")
    passback_params: Optional[StrictStr] = Field(default=None, alias="passbackParams")
    pay_amount: Optional[StrictStr] = Field(default=None, alias="payAmount")
    pay_currency: Optional[StrictStr] = Field(default=None, alias="payCurrency")
    payment_info_with_id_list: Optional[List[PaymentInfoWithId]] = Field(default=None, alias="paymentInfoWithIdList")
    period_scene: Optional[StrictStr] = Field(default=None, alias="periodScene")
    point_amount: Optional[StrictStr] = Field(default=None, alias="pointAmount")
    pre_auth_pay_amount: Optional[StrictStr] = Field(default=None, alias="preAuthPayAmount")
    receipt_amount: Optional[StrictStr] = Field(default=None, alias="receiptAmount")
    receipt_currency_type: Optional[StrictStr] = Field(default=None, alias="receiptCurrencyType")
    req_goods_detail: Optional[List[GoodsDetail]] = Field(default=None, alias="reqGoodsDetail")
    send_pay_date: Optional[StrictStr] = Field(default=None, alias="sendPayDate")
    settle_amount: Optional[StrictStr] = Field(default=None, alias="settleAmount")
    settle_currency: Optional[StrictStr] = Field(default=None, alias="settleCurrency")
    settle_trans_rate: Optional[StrictStr] = Field(default=None, alias="settleTransRate")
    settlement_id: Optional[StrictStr] = Field(default=None, alias="settlementId")
    store_id: Optional[StrictStr] = Field(default=None, alias="storeId")
    store_name: Optional[StrictStr] = Field(default=None, alias="storeName")
    subject: Optional[StrictStr] = None
    tap_pay_info: Optional[TapPayInfo] = Field(default=None, alias="tapPayInfo")
    terminal_id: Optional[StrictStr] = Field(default=None, alias="terminalId")
    total_amount: Optional[StrictStr] = Field(default=None, alias="totalAmount")
    trade_no: Optional[StrictStr] = Field(default=None, alias="tradeNo")
    trade_settle_info: Optional[TradeSettleInfo] = Field(default=None, alias="tradeSettleInfo")
    trade_status: Optional[StrictStr] = Field(default=None, alias="tradeStatus")
    trans_currency: Optional[StrictStr] = Field(default=None, alias="transCurrency")
    trans_pay_rate: Optional[StrictStr] = Field(default=None, alias="transPayRate")
    voucher_detail_list: Optional[List[VoucherDetail]] = Field(default=None, alias="voucherDetailList")
    __properties: ClassVar[List[str]] = ["code", "msg", "subCode", "subMsg", "isError", "additionalStatus", "alipayStoreId", "alipaySubMerchantId", "asyncPayApplyStatus", "authTradePayMode", "bizSettleMode", "bkagentRespInfo", "body", "buyerLogonId", "buyerOpenId", "buyerPayAmount", "buyerUserId", "buyerUserName", "buyerUserType", "cashierType", "chargeAmount", "chargeFlags", "chargeInfoList", "creditBizOrderId", "creditPayMode", "discountAmount", "discountGoodsDetail", "enterprisePayInfo", "extInfos", "fulfillmentDetailList", "fundBillList", "hbFqPayInfo", "hybAmount", "industrySepcDetail", "industrySepcDetailAcc", "industrySepcDetailGov", "intactChargeInfoList", "invoiceAmount", "mdiscountAmount", "medicalInsuranceInfo", "openId", "outTradeNo", "passbackParams", "payAmount", "payCurrency", "paymentInfoWithIdList", "periodScene", "pointAmount", "preAuthPayAmount", "receiptAmount", "receiptCurrencyType", "reqGoodsDetail", "sendPayDate", "settleAmount", "settleCurrency", "settleTransRate", "settlementId", "storeId", "storeName", "subject", "tapPayInfo", "terminalId", "totalAmount", "tradeNo", "tradeSettleInfo", "tradeStatus", "transCurrency", "transPayRate", "voucherDetailList"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AlipayTradeQueryResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "is_error",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of bkagent_resp_info
        if self.bkagent_resp_info:
            _dict['bkagentRespInfo'] = self.bkagent_resp_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in charge_info_list (list)
        _items = []
        if self.charge_info_list:
            for _item_charge_info_list in self.charge_info_list:
                if _item_charge_info_list:
                    _items.append(_item_charge_info_list.to_dict())
            _dict['chargeInfoList'] = _items
        # override the default output from pydantic by calling `to_dict()` of enterprise_pay_info
        if self.enterprise_pay_info:
            _dict['enterprisePayInfo'] = self.enterprise_pay_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in fulfillment_detail_list (list)
        _items = []
        if self.fulfillment_detail_list:
            for _item_fulfillment_detail_list in self.fulfillment_detail_list:
                if _item_fulfillment_detail_list:
                    _items.append(_item_fulfillment_detail_list.to_dict())
            _dict['fulfillmentDetailList'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in fund_bill_list (list)
        _items = []
        if self.fund_bill_list:
            for _item_fund_bill_list in self.fund_bill_list:
                if _item_fund_bill_list:
                    _items.append(_item_fund_bill_list.to_dict())
            _dict['fundBillList'] = _items
        # override the default output from pydantic by calling `to_dict()` of hb_fq_pay_info
        if self.hb_fq_pay_info:
            _dict['hbFqPayInfo'] = self.hb_fq_pay_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in intact_charge_info_list (list)
        _items = []
        if self.intact_charge_info_list:
            for _item_intact_charge_info_list in self.intact_charge_info_list:
                if _item_intact_charge_info_list:
                    _items.append(_item_intact_charge_info_list.to_dict())
            _dict['intactChargeInfoList'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in payment_info_with_id_list (list)
        _items = []
        if self.payment_info_with_id_list:
            for _item_payment_info_with_id_list in self.payment_info_with_id_list:
                if _item_payment_info_with_id_list:
                    _items.append(_item_payment_info_with_id_list.to_dict())
            _dict['paymentInfoWithIdList'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in req_goods_detail (list)
        _items = []
        if self.req_goods_detail:
            for _item_req_goods_detail in self.req_goods_detail:
                if _item_req_goods_detail:
                    _items.append(_item_req_goods_detail.to_dict())
            _dict['reqGoodsDetail'] = _items
        # override the default output from pydantic by calling `to_dict()` of tap_pay_info
        if self.tap_pay_info:
            _dict['tapPayInfo'] = self.tap_pay_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of trade_settle_info
        if self.trade_settle_info:
            _dict['tradeSettleInfo'] = self.trade_settle_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in voucher_detail_list (list)
        _items = []
        if self.voucher_detail_list:
            for _item_voucher_detail_list in self.voucher_detail_list:
                if _item_voucher_detail_list:
                    _items.append(_item_voucher_detail_list.to_dict())
            _dict['voucherDetailList'] = _items
        # set to None if code (nullable) is None
        # and model_fields_set contains the field
        if self.code is None and "code" in self.model_fields_set:
            _dict['code'] = None

        # set to None if msg (nullable) is None
        # and model_fields_set contains the field
        if self.msg is None and "msg" in self.model_fields_set:
            _dict['msg'] = None

        # set to None if sub_code (nullable) is None
        # and model_fields_set contains the field
        if self.sub_code is None and "sub_code" in self.model_fields_set:
            _dict['subCode'] = None

        # set to None if sub_msg (nullable) is None
        # and model_fields_set contains the field
        if self.sub_msg is None and "sub_msg" in self.model_fields_set:
            _dict['subMsg'] = None

        # set to None if additional_status (nullable) is None
        # and model_fields_set contains the field
        if self.additional_status is None and "additional_status" in self.model_fields_set:
            _dict['additionalStatus'] = None

        # set to None if alipay_store_id (nullable) is None
        # and model_fields_set contains the field
        if self.alipay_store_id is None and "alipay_store_id" in self.model_fields_set:
            _dict['alipayStoreId'] = None

        # set to None if alipay_sub_merchant_id (nullable) is None
        # and model_fields_set contains the field
        if self.alipay_sub_merchant_id is None and "alipay_sub_merchant_id" in self.model_fields_set:
            _dict['alipaySubMerchantId'] = None

        # set to None if async_pay_apply_status (nullable) is None
        # and model_fields_set contains the field
        if self.async_pay_apply_status is None and "async_pay_apply_status" in self.model_fields_set:
            _dict['asyncPayApplyStatus'] = None

        # set to None if auth_trade_pay_mode (nullable) is None
        # and model_fields_set contains the field
        if self.auth_trade_pay_mode is None and "auth_trade_pay_mode" in self.model_fields_set:
            _dict['authTradePayMode'] = None

        # set to None if biz_settle_mode (nullable) is None
        # and model_fields_set contains the field
        if self.biz_settle_mode is None and "biz_settle_mode" in self.model_fields_set:
            _dict['bizSettleMode'] = None

        # set to None if body (nullable) is None
        # and model_fields_set contains the field
        if self.body is None and "body" in self.model_fields_set:
            _dict['body'] = None

        # set to None if buyer_logon_id (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_logon_id is None and "buyer_logon_id" in self.model_fields_set:
            _dict['buyerLogonId'] = None

        # set to None if buyer_open_id (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_open_id is None and "buyer_open_id" in self.model_fields_set:
            _dict['buyerOpenId'] = None

        # set to None if buyer_pay_amount (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_pay_amount is None and "buyer_pay_amount" in self.model_fields_set:
            _dict['buyerPayAmount'] = None

        # set to None if buyer_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_user_id is None and "buyer_user_id" in self.model_fields_set:
            _dict['buyerUserId'] = None

        # set to None if buyer_user_name (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_user_name is None and "buyer_user_name" in self.model_fields_set:
            _dict['buyerUserName'] = None

        # set to None if buyer_user_type (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_user_type is None and "buyer_user_type" in self.model_fields_set:
            _dict['buyerUserType'] = None

        # set to None if cashier_type (nullable) is None
        # and model_fields_set contains the field
        if self.cashier_type is None and "cashier_type" in self.model_fields_set:
            _dict['cashierType'] = None

        # set to None if charge_amount (nullable) is None
        # and model_fields_set contains the field
        if self.charge_amount is None and "charge_amount" in self.model_fields_set:
            _dict['chargeAmount'] = None

        # set to None if charge_flags (nullable) is None
        # and model_fields_set contains the field
        if self.charge_flags is None and "charge_flags" in self.model_fields_set:
            _dict['chargeFlags'] = None

        # set to None if charge_info_list (nullable) is None
        # and model_fields_set contains the field
        if self.charge_info_list is None and "charge_info_list" in self.model_fields_set:
            _dict['chargeInfoList'] = None

        # set to None if credit_biz_order_id (nullable) is None
        # and model_fields_set contains the field
        if self.credit_biz_order_id is None and "credit_biz_order_id" in self.model_fields_set:
            _dict['creditBizOrderId'] = None

        # set to None if credit_pay_mode (nullable) is None
        # and model_fields_set contains the field
        if self.credit_pay_mode is None and "credit_pay_mode" in self.model_fields_set:
            _dict['creditPayMode'] = None

        # set to None if discount_amount (nullable) is None
        # and model_fields_set contains the field
        if self.discount_amount is None and "discount_amount" in self.model_fields_set:
            _dict['discountAmount'] = None

        # set to None if discount_goods_detail (nullable) is None
        # and model_fields_set contains the field
        if self.discount_goods_detail is None and "discount_goods_detail" in self.model_fields_set:
            _dict['discountGoodsDetail'] = None

        # set to None if ext_infos (nullable) is None
        # and model_fields_set contains the field
        if self.ext_infos is None and "ext_infos" in self.model_fields_set:
            _dict['extInfos'] = None

        # set to None if fulfillment_detail_list (nullable) is None
        # and model_fields_set contains the field
        if self.fulfillment_detail_list is None and "fulfillment_detail_list" in self.model_fields_set:
            _dict['fulfillmentDetailList'] = None

        # set to None if fund_bill_list (nullable) is None
        # and model_fields_set contains the field
        if self.fund_bill_list is None and "fund_bill_list" in self.model_fields_set:
            _dict['fundBillList'] = None

        # set to None if hyb_amount (nullable) is None
        # and model_fields_set contains the field
        if self.hyb_amount is None and "hyb_amount" in self.model_fields_set:
            _dict['hybAmount'] = None

        # set to None if industry_sepc_detail (nullable) is None
        # and model_fields_set contains the field
        if self.industry_sepc_detail is None and "industry_sepc_detail" in self.model_fields_set:
            _dict['industrySepcDetail'] = None

        # set to None if industry_sepc_detail_acc (nullable) is None
        # and model_fields_set contains the field
        if self.industry_sepc_detail_acc is None and "industry_sepc_detail_acc" in self.model_fields_set:
            _dict['industrySepcDetailAcc'] = None

        # set to None if industry_sepc_detail_gov (nullable) is None
        # and model_fields_set contains the field
        if self.industry_sepc_detail_gov is None and "industry_sepc_detail_gov" in self.model_fields_set:
            _dict['industrySepcDetailGov'] = None

        # set to None if intact_charge_info_list (nullable) is None
        # and model_fields_set contains the field
        if self.intact_charge_info_list is None and "intact_charge_info_list" in self.model_fields_set:
            _dict['intactChargeInfoList'] = None

        # set to None if invoice_amount (nullable) is None
        # and model_fields_set contains the field
        if self.invoice_amount is None and "invoice_amount" in self.model_fields_set:
            _dict['invoiceAmount'] = None

        # set to None if mdiscount_amount (nullable) is None
        # and model_fields_set contains the field
        if self.mdiscount_amount is None and "mdiscount_amount" in self.model_fields_set:
            _dict['mdiscountAmount'] = None

        # set to None if medical_insurance_info (nullable) is None
        # and model_fields_set contains the field
        if self.medical_insurance_info is None and "medical_insurance_info" in self.model_fields_set:
            _dict['medicalInsuranceInfo'] = None

        # set to None if open_id (nullable) is None
        # and model_fields_set contains the field
        if self.open_id is None and "open_id" in self.model_fields_set:
            _dict['openId'] = None

        # set to None if out_trade_no (nullable) is None
        # and model_fields_set contains the field
        if self.out_trade_no is None and "out_trade_no" in self.model_fields_set:
            _dict['outTradeNo'] = None

        # set to None if passback_params (nullable) is None
        # and model_fields_set contains the field
        if self.passback_params is None and "passback_params" in self.model_fields_set:
            _dict['passbackParams'] = None

        # set to None if pay_amount (nullable) is None
        # and model_fields_set contains the field
        if self.pay_amount is None and "pay_amount" in self.model_fields_set:
            _dict['payAmount'] = None

        # set to None if pay_currency (nullable) is None
        # and model_fields_set contains the field
        if self.pay_currency is None and "pay_currency" in self.model_fields_set:
            _dict['payCurrency'] = None

        # set to None if payment_info_with_id_list (nullable) is None
        # and model_fields_set contains the field
        if self.payment_info_with_id_list is None and "payment_info_with_id_list" in self.model_fields_set:
            _dict['paymentInfoWithIdList'] = None

        # set to None if period_scene (nullable) is None
        # and model_fields_set contains the field
        if self.period_scene is None and "period_scene" in self.model_fields_set:
            _dict['periodScene'] = None

        # set to None if point_amount (nullable) is None
        # and model_fields_set contains the field
        if self.point_amount is None and "point_amount" in self.model_fields_set:
            _dict['pointAmount'] = None

        # set to None if pre_auth_pay_amount (nullable) is None
        # and model_fields_set contains the field
        if self.pre_auth_pay_amount is None and "pre_auth_pay_amount" in self.model_fields_set:
            _dict['preAuthPayAmount'] = None

        # set to None if receipt_amount (nullable) is None
        # and model_fields_set contains the field
        if self.receipt_amount is None and "receipt_amount" in self.model_fields_set:
            _dict['receiptAmount'] = None

        # set to None if receipt_currency_type (nullable) is None
        # and model_fields_set contains the field
        if self.receipt_currency_type is None and "receipt_currency_type" in self.model_fields_set:
            _dict['receiptCurrencyType'] = None

        # set to None if req_goods_detail (nullable) is None
        # and model_fields_set contains the field
        if self.req_goods_detail is None and "req_goods_detail" in self.model_fields_set:
            _dict['reqGoodsDetail'] = None

        # set to None if send_pay_date (nullable) is None
        # and model_fields_set contains the field
        if self.send_pay_date is None and "send_pay_date" in self.model_fields_set:
            _dict['sendPayDate'] = None

        # set to None if settle_amount (nullable) is None
        # and model_fields_set contains the field
        if self.settle_amount is None and "settle_amount" in self.model_fields_set:
            _dict['settleAmount'] = None

        # set to None if settle_currency (nullable) is None
        # and model_fields_set contains the field
        if self.settle_currency is None and "settle_currency" in self.model_fields_set:
            _dict['settleCurrency'] = None

        # set to None if settle_trans_rate (nullable) is None
        # and model_fields_set contains the field
        if self.settle_trans_rate is None and "settle_trans_rate" in self.model_fields_set:
            _dict['settleTransRate'] = None

        # set to None if settlement_id (nullable) is None
        # and model_fields_set contains the field
        if self.settlement_id is None and "settlement_id" in self.model_fields_set:
            _dict['settlementId'] = None

        # set to None if store_id (nullable) is None
        # and model_fields_set contains the field
        if self.store_id is None and "store_id" in self.model_fields_set:
            _dict['storeId'] = None

        # set to None if store_name (nullable) is None
        # and model_fields_set contains the field
        if self.store_name is None and "store_name" in self.model_fields_set:
            _dict['storeName'] = None

        # set to None if subject (nullable) is None
        # and model_fields_set contains the field
        if self.subject is None and "subject" in self.model_fields_set:
            _dict['subject'] = None

        # set to None if terminal_id (nullable) is None
        # and model_fields_set contains the field
        if self.terminal_id is None and "terminal_id" in self.model_fields_set:
            _dict['terminalId'] = None

        # set to None if total_amount (nullable) is None
        # and model_fields_set contains the field
        if self.total_amount is None and "total_amount" in self.model_fields_set:
            _dict['totalAmount'] = None

        # set to None if trade_no (nullable) is None
        # and model_fields_set contains the field
        if self.trade_no is None and "trade_no" in self.model_fields_set:
            _dict['tradeNo'] = None

        # set to None if trade_status (nullable) is None
        # and model_fields_set contains the field
        if self.trade_status is None and "trade_status" in self.model_fields_set:
            _dict['tradeStatus'] = None

        # set to None if trans_currency (nullable) is None
        # and model_fields_set contains the field
        if self.trans_currency is None and "trans_currency" in self.model_fields_set:
            _dict['transCurrency'] = None

        # set to None if trans_pay_rate (nullable) is None
        # and model_fields_set contains the field
        if self.trans_pay_rate is None and "trans_pay_rate" in self.model_fields_set:
            _dict['transPayRate'] = None

        # set to None if voucher_detail_list (nullable) is None
        # and model_fields_set contains the field
        if self.voucher_detail_list is None and "voucher_detail_list" in self.model_fields_set:
            _dict['voucherDetailList'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AlipayTradeQueryResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "code": obj.get("code"),
            "msg": obj.get("msg"),
            "subCode": obj.get("subCode"),
            "subMsg": obj.get("subMsg"),
            "isError": obj.get("isError"),
            "additionalStatus": obj.get("additionalStatus"),
            "alipayStoreId": obj.get("alipayStoreId"),
            "alipaySubMerchantId": obj.get("alipaySubMerchantId"),
            "asyncPayApplyStatus": obj.get("asyncPayApplyStatus"),
            "authTradePayMode": obj.get("authTradePayMode"),
            "bizSettleMode": obj.get("bizSettleMode"),
            "bkagentRespInfo": BkAgentRespInfo.from_dict(obj["bkagentRespInfo"]) if obj.get("bkagentRespInfo") is not None else None,
            "body": obj.get("body"),
            "buyerLogonId": obj.get("buyerLogonId"),
            "buyerOpenId": obj.get("buyerOpenId"),
            "buyerPayAmount": obj.get("buyerPayAmount"),
            "buyerUserId": obj.get("buyerUserId"),
            "buyerUserName": obj.get("buyerUserName"),
            "buyerUserType": obj.get("buyerUserType"),
            "cashierType": obj.get("cashierType"),
            "chargeAmount": obj.get("chargeAmount"),
            "chargeFlags": obj.get("chargeFlags"),
            "chargeInfoList": [ChargeInfo.from_dict(_item) for _item in obj["chargeInfoList"]] if obj.get("chargeInfoList") is not None else None,
            "creditBizOrderId": obj.get("creditBizOrderId"),
            "creditPayMode": obj.get("creditPayMode"),
            "discountAmount": obj.get("discountAmount"),
            "discountGoodsDetail": obj.get("discountGoodsDetail"),
            "enterprisePayInfo": EnterprisePayInfo.from_dict(obj["enterprisePayInfo"]) if obj.get("enterprisePayInfo") is not None else None,
            "extInfos": obj.get("extInfos"),
            "fulfillmentDetailList": [FulfillmentDetail.from_dict(_item) for _item in obj["fulfillmentDetailList"]] if obj.get("fulfillmentDetailList") is not None else None,
            "fundBillList": [TradeFundBill.from_dict(_item) for _item in obj["fundBillList"]] if obj.get("fundBillList") is not None else None,
            "hbFqPayInfo": HbFqPayInfo.from_dict(obj["hbFqPayInfo"]) if obj.get("hbFqPayInfo") is not None else None,
            "hybAmount": obj.get("hybAmount"),
            "industrySepcDetail": obj.get("industrySepcDetail"),
            "industrySepcDetailAcc": obj.get("industrySepcDetailAcc"),
            "industrySepcDetailGov": obj.get("industrySepcDetailGov"),
            "intactChargeInfoList": [IntactChargeInfo.from_dict(_item) for _item in obj["intactChargeInfoList"]] if obj.get("intactChargeInfoList") is not None else None,
            "invoiceAmount": obj.get("invoiceAmount"),
            "mdiscountAmount": obj.get("mdiscountAmount"),
            "medicalInsuranceInfo": obj.get("medicalInsuranceInfo"),
            "openId": obj.get("openId"),
            "outTradeNo": obj.get("outTradeNo"),
            "passbackParams": obj.get("passbackParams"),
            "payAmount": obj.get("payAmount"),
            "payCurrency": obj.get("payCurrency"),
            "paymentInfoWithIdList": [PaymentInfoWithId.from_dict(_item) for _item in obj["paymentInfoWithIdList"]] if obj.get("paymentInfoWithIdList") is not None else None,
            "periodScene": obj.get("periodScene"),
            "pointAmount": obj.get("pointAmount"),
            "preAuthPayAmount": obj.get("preAuthPayAmount"),
            "receiptAmount": obj.get("receiptAmount"),
            "receiptCurrencyType": obj.get("receiptCurrencyType"),
            "reqGoodsDetail": [GoodsDetail.from_dict(_item) for _item in obj["reqGoodsDetail"]] if obj.get("reqGoodsDetail") is not None else None,
            "sendPayDate": obj.get("sendPayDate"),
            "settleAmount": obj.get("settleAmount"),
            "settleCurrency": obj.get("settleCurrency"),
            "settleTransRate": obj.get("settleTransRate"),
            "settlementId": obj.get("settlementId"),
            "storeId": obj.get("storeId"),
            "storeName": obj.get("storeName"),
            "subject": obj.get("subject"),
            "tapPayInfo": TapPayInfo.from_dict(obj["tapPayInfo"]) if obj.get("tapPayInfo") is not None else None,
            "terminalId": obj.get("terminalId"),
            "totalAmount": obj.get("totalAmount"),
            "tradeNo": obj.get("tradeNo"),
            "tradeSettleInfo": TradeSettleInfo.from_dict(obj["tradeSettleInfo"]) if obj.get("tradeSettleInfo") is not None else None,
            "tradeStatus": obj.get("tradeStatus"),
            "transCurrency": obj.get("transCurrency"),
            "transPayRate": obj.get("transPayRate"),
            "voucherDetailList": [VoucherDetail.from_dict(_item) for _item in obj["voucherDetailList"]] if obj.get("voucherDetailList") is not None else None
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class UserLogins(BaseModel):
    """
    用户外部账号
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="唯一标识符")
    user_id: Optional[StrictInt] = Field(default=None, description="关联的用户ID", alias="userID")
    platform_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="第三方平台名称", alias="platformName")
    platform: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="第三方平台")
    union_id: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="第三方平台唯一标识", alias="unionID")
    avatar: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="用户头像")
    data: Optional[StrictStr] = Field(default=None, description="扩展数据")
    enable: Optional[StrictBool] = Field(default=None, description="启用")
    create_date: Optional[datetime] = Field(default=None, description="创建时间", alias="createDate")
    last_update: Optional[datetime] = Field(default=None, description="最后更新时间", alias="lastUpdate")
    __properties: ClassVar[List[str]] = ["id", "userID", "platformName", "platform", "unionID", "avatar", "data", "enable", "createDate", "lastUpdate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserLogins from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if platform_name (nullable) is None
        # and model_fields_set contains the field
        if self.platform_name is None and "platform_name" in self.model_fields_set:
            _dict['platformName'] = None

        # set to None if platform (nullable) is None
        # and model_fields_set contains the field
        if self.platform is None and "platform" in self.model_fields_set:
            _dict['platform'] = None

        # set to None if union_id (nullable) is None
        # and model_fields_set contains the field
        if self.union_id is None and "union_id" in self.model_fields_set:
            _dict['unionID'] = None

        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserLogins from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "userID": obj.get("userID"),
            "platformName": obj.get("platformName"),
            "platform": obj.get("platform"),
            "unionID": obj.get("unionID"),
            "avatar": obj.get("avatar"),
            "data": obj.get("data"),
            "enable": obj.get("enable"),
            "createDate": obj.get("createDate"),
            "lastUpdate": obj.get("lastUpdate")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ZSGF.Client.models.refund_sub_fee import RefundSubFee
from typing import Optional, Set
from typing_extensions import Self

class RefundChargeInfo(BaseModel):
    """
    RefundChargeInfo
    """ # noqa: E501
    charge_type: Optional[StrictStr] = Field(default=None, alias="chargeType")
    refund_charge_fee: Optional[StrictStr] = Field(default=None, alias="refundChargeFee")
    refund_sub_fee_detail_list: Optional[List[RefundSubFee]] = Field(default=None, alias="refundSubFeeDetailList")
    switch_fee_rate: Optional[StrictStr] = Field(default=None, alias="switchFeeRate")
    __properties: ClassVar[List[str]] = ["chargeType", "refundChargeFee", "refundSubFeeDetailList", "switchFeeRate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RefundChargeInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in refund_sub_fee_detail_list (list)
        _items = []
        if self.refund_sub_fee_detail_list:
            for _item_refund_sub_fee_detail_list in self.refund_sub_fee_detail_list:
                if _item_refund_sub_fee_detail_list:
                    _items.append(_item_refund_sub_fee_detail_list.to_dict())
            _dict['refundSubFeeDetailList'] = _items
        # set to None if charge_type (nullable) is None
        # and model_fields_set contains the field
        if self.charge_type is None and "charge_type" in self.model_fields_set:
            _dict['chargeType'] = None

        # set to None if refund_charge_fee (nullable) is None
        # and model_fields_set contains the field
        if self.refund_charge_fee is None and "refund_charge_fee" in self.model_fields_set:
            _dict['refundChargeFee'] = None

        # set to None if refund_sub_fee_detail_list (nullable) is None
        # and model_fields_set contains the field
        if self.refund_sub_fee_detail_list is None and "refund_sub_fee_detail_list" in self.model_fields_set:
            _dict['refundSubFeeDetailList'] = None

        # set to None if switch_fee_rate (nullable) is None
        # and model_fields_set contains the field
        if self.switch_fee_rate is None and "switch_fee_rate" in self.model_fields_set:
            _dict['switchFeeRate'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RefundChargeInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "chargeType": obj.get("chargeType"),
            "refundChargeFee": obj.get("refundChargeFee"),
            "refundSubFeeDetailList": [RefundSubFee.from_dict(_item) for _item in obj["refundSubFeeDetailList"]] if obj.get("refundSubFeeDetailList") is not None else None,
            "switchFeeRate": obj.get("switchFeeRate")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class GeoLocationModel(BaseModel):
    """
    GeoLocationModel
    """ # noqa: E501
    location_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="地点的名称", alias="locationName")
    latitude: Union[StrictFloat, StrictInt] = Field(description="纬度")
    longitude: Union[StrictFloat, StrictInt] = Field(description="经度")
    location_type: Annotated[str, Field(min_length=1, strict=True, max_length=20)] = Field(description="地点的类型，如家庭、工作、学校等", alias="locationType")
    recipient_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="收货人姓名", alias="recipientName")
    phone_number: Optional[StrictStr] = Field(default=None, description="收货人联系电话", alias="phoneNumber")
    email: Optional[StrictStr] = Field(default=None, description="收货人电子邮件")
    country: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="国家")
    state: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="州/省")
    city: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="城市")
    district: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="区/县")
    street: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="街道")
    zip_code: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="邮政编码", alias="zipCode")
    address: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, description="详细的地址信息")
    map_type: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="地址类型，百度、高德、谷歌", alias="mapType")
    remark: Optional[Annotated[str, Field(strict=True, max_length=5000)]] = Field(default=None, description="备注")
    tags: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, description="标签")
    enable: Optional[StrictBool] = Field(default=None, description="启用")
    show_index: Optional[StrictInt] = Field(default=None, description="排序", alias="showIndex")
    create_date: Optional[datetime] = Field(default=None, description="创建时间", alias="createDate")
    last_update: Optional[datetime] = Field(default=None, description="最后更新的时间", alias="lastUpdate")
    __properties: ClassVar[List[str]] = ["locationName", "latitude", "longitude", "locationType", "recipientName", "phoneNumber", "email", "country", "state", "city", "district", "street", "zipCode", "address", "mapType", "remark", "tags", "enable", "showIndex", "createDate", "lastUpdate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GeoLocationModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if location_name (nullable) is None
        # and model_fields_set contains the field
        if self.location_name is None and "location_name" in self.model_fields_set:
            _dict['locationName'] = None

        # set to None if recipient_name (nullable) is None
        # and model_fields_set contains the field
        if self.recipient_name is None and "recipient_name" in self.model_fields_set:
            _dict['recipientName'] = None

        # set to None if phone_number (nullable) is None
        # and model_fields_set contains the field
        if self.phone_number is None and "phone_number" in self.model_fields_set:
            _dict['phoneNumber'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict['state'] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if district (nullable) is None
        # and model_fields_set contains the field
        if self.district is None and "district" in self.model_fields_set:
            _dict['district'] = None

        # set to None if street (nullable) is None
        # and model_fields_set contains the field
        if self.street is None and "street" in self.model_fields_set:
            _dict['street'] = None

        # set to None if zip_code (nullable) is None
        # and model_fields_set contains the field
        if self.zip_code is None and "zip_code" in self.model_fields_set:
            _dict['zipCode'] = None

        # set to None if address (nullable) is None
        # and model_fields_set contains the field
        if self.address is None and "address" in self.model_fields_set:
            _dict['address'] = None

        # set to None if map_type (nullable) is None
        # and model_fields_set contains the field
        if self.map_type is None and "map_type" in self.model_fields_set:
            _dict['mapType'] = None

        # set to None if remark (nullable) is None
        # and model_fields_set contains the field
        if self.remark is None and "remark" in self.model_fields_set:
            _dict['remark'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if enable (nullable) is None
        # and model_fields_set contains the field
        if self.enable is None and "enable" in self.model_fields_set:
            _dict['enable'] = None

        # set to None if show_index (nullable) is None
        # and model_fields_set contains the field
        if self.show_index is None and "show_index" in self.model_fields_set:
            _dict['showIndex'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GeoLocationModel from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "locationName": obj.get("locationName"),
            "latitude": obj.get("latitude"),
            "longitude": obj.get("longitude"),
            "locationType": obj.get("locationType"),
            "recipientName": obj.get("recipientName"),
            "phoneNumber": obj.get("phoneNumber"),
            "email": obj.get("email"),
            "country": obj.get("country"),
            "state": obj.get("state"),
            "city": obj.get("city"),
            "district": obj.get("district"),
            "street": obj.get("street"),
            "zipCode": obj.get("zipCode"),
            "address": obj.get("address"),
            "mapType": obj.get("mapType"),
            "remark": obj.get("remark"),
            "tags": obj.get("tags"),
            "enable": obj.get("enable"),
            "showIndex": obj.get("showIndex"),
            "createDate": obj.get("createDate"),
            "lastUpdate": obj.get("lastUpdate")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ReturnPageNotifyRequest(BaseModel):
    """
    支付宝返回页面通知请求
    """ # noqa: E501
    app_id: Optional[StrictStr] = Field(default=None, description="应用ID")
    auth_app_id: Optional[StrictStr] = Field(default=None, description="授权应用ID")
    charset: Optional[StrictStr] = Field(default=None, description="字符集")
    method: Optional[StrictStr] = Field(default=None, description="接口名称")
    out_trade_no: Optional[StrictStr] = Field(default=None, description="商户订单号")
    seller_id: Optional[StrictStr] = Field(default=None, description="卖家支付宝用户号")
    sign: Optional[StrictStr] = Field(default=None, description="签名")
    sign_type: Optional[StrictStr] = Field(default=None, description="签名类型")
    timestamp: Optional[StrictStr] = Field(default=None, description="时间戳")
    total_amount: Optional[StrictStr] = Field(default=None, description="订单总金额")
    trade_no: Optional[StrictStr] = Field(default=None, description="支付宝交易号")
    version: Optional[StrictStr] = Field(default=None, description="接口版本")
    __properties: ClassVar[List[str]] = ["app_id", "auth_app_id", "charset", "method", "out_trade_no", "seller_id", "sign", "sign_type", "timestamp", "total_amount", "trade_no", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReturnPageNotifyRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if app_id (nullable) is None
        # and model_fields_set contains the field
        if self.app_id is None and "app_id" in self.model_fields_set:
            _dict['app_id'] = None

        # set to None if auth_app_id (nullable) is None
        # and model_fields_set contains the field
        if self.auth_app_id is None and "auth_app_id" in self.model_fields_set:
            _dict['auth_app_id'] = None

        # set to None if charset (nullable) is None
        # and model_fields_set contains the field
        if self.charset is None and "charset" in self.model_fields_set:
            _dict['charset'] = None

        # set to None if method (nullable) is None
        # and model_fields_set contains the field
        if self.method is None and "method" in self.model_fields_set:
            _dict['method'] = None

        # set to None if out_trade_no (nullable) is None
        # and model_fields_set contains the field
        if self.out_trade_no is None and "out_trade_no" in self.model_fields_set:
            _dict['out_trade_no'] = None

        # set to None if seller_id (nullable) is None
        # and model_fields_set contains the field
        if self.seller_id is None and "seller_id" in self.model_fields_set:
            _dict['seller_id'] = None

        # set to None if sign (nullable) is None
        # and model_fields_set contains the field
        if self.sign is None and "sign" in self.model_fields_set:
            _dict['sign'] = None

        # set to None if sign_type (nullable) is None
        # and model_fields_set contains the field
        if self.sign_type is None and "sign_type" in self.model_fields_set:
            _dict['sign_type'] = None

        # set to None if timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.timestamp is None and "timestamp" in self.model_fields_set:
            _dict['timestamp'] = None

        # set to None if total_amount (nullable) is None
        # and model_fields_set contains the field
        if self.total_amount is None and "total_amount" in self.model_fields_set:
            _dict['total_amount'] = None

        # set to None if trade_no (nullable) is None
        # and model_fields_set contains the field
        if self.trade_no is None and "trade_no" in self.model_fields_set:
            _dict['trade_no'] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReturnPageNotifyRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "app_id": obj.get("app_id"),
            "auth_app_id": obj.get("auth_app_id"),
            "charset": obj.get("charset"),
            "method": obj.get("method"),
            "out_trade_no": obj.get("out_trade_no"),
            "seller_id": obj.get("seller_id"),
            "sign": obj.get("sign"),
            "sign_type": obj.get("sign_type"),
            "timestamp": obj.get("timestamp"),
            "total_amount": obj.get("total_amount"),
            "trade_no": obj.get("trade_no"),
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class User(BaseModel):
    """
    用户
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="用户唯一标识")
    platform: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="用户所在平台")
    union_id: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="用户所在平台的唯一标识", alias="unionID")
    nick_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="昵称", alias="nickName")
    avatar: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="头像")
    data: Optional[StrictStr] = Field(default=None, description="其他数据")
    user_name: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="用户名", alias="userName")
    pwd: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="用户密码")
    email: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="邮箱地址")
    email_is_valid: Optional[StrictBool] = Field(default=None, description="邮箱已验证", alias="emailIsValid")
    phone: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="手机号码")
    phone_is_valid: Optional[StrictBool] = Field(default=None, description="手机号码已验证", alias="phoneIsValid")
    relation_chain: Optional[StrictStr] = Field(default=None, description="关系链", alias="relationChain")
    interest_tags: Optional[StrictStr] = Field(default=None, description="兴趣标签", alias="interestTags")
    biography: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="个人简介")
    gender: Optional[Annotated[str, Field(strict=True, max_length=15)]] = Field(default=None, description="性别")
    birthday: Optional[datetime] = Field(default=None, description="生日")
    occupation: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="职业")
    education: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="学历")
    contact: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="联系方式")
    languages: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="语言")
    social_links: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="社交网络链接", alias="socialLinks")
    relationship_status: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="婚姻状态", alias="relationshipStatus")
    company: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="公司")
    industry: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="行业")
    company_position: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="行业职位", alias="companyPosition")
    private_settings: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="私密设置", alias="privateSettings")
    is_lock: Optional[StrictBool] = Field(default=None, description="账户是否锁定", alias="isLock")
    lock_until: Optional[datetime] = Field(default=None, description="账户锁定截止时间", alias="lockUntil")
    enable_user_name_sign_in: Optional[StrictBool] = Field(default=None, description="能使用用户名登录", alias="enableUserNameSignIn")
    enable_email_sign_in: Optional[StrictBool] = Field(default=None, description="能使用邮箱登录", alias="enableEmailSignIn")
    enable_phone_sign_in: Optional[StrictBool] = Field(default=None, description="能使用电话号码登录", alias="enablePhoneSignIn")
    enable_union_id_sign_in: Optional[StrictBool] = Field(default=None, description="能使用联合身份标识登录", alias="enableUnionIDSignIn")
    enable_o_auth: Optional[StrictBool] = Field(default=None, description="能使用OAuth认证方式登录", alias="enableOAuth")
    enable2_fa_auth: Optional[StrictBool] = Field(default=None, description="启用双因素认证登录", alias="enable2FAAuth")
    create_date: Optional[datetime] = Field(default=None, description="创建时间", alias="createDate")
    last_update: Optional[datetime] = Field(default=None, description="最后更新时间", alias="lastUpdate")
    __properties: ClassVar[List[str]] = ["id", "platform", "unionID", "nickName", "avatar", "data", "userName", "pwd", "email", "emailIsValid", "phone", "phoneIsValid", "relationChain", "interestTags", "biography", "gender", "birthday", "occupation", "education", "contact", "languages", "socialLinks", "relationshipStatus", "company", "industry", "companyPosition", "privateSettings", "isLock", "lockUntil", "enableUserNameSignIn", "enableEmailSignIn", "enablePhoneSignIn", "enableUnionIDSignIn", "enableOAuth", "enable2FAAuth", "createDate", "lastUpdate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of User from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if platform (nullable) is None
        # and model_fields_set contains the field
        if self.platform is None and "platform" in self.model_fields_set:
            _dict['platform'] = None

        # set to None if union_id (nullable) is None
        # and model_fields_set contains the field
        if self.union_id is None and "union_id" in self.model_fields_set:
            _dict['unionID'] = None

        # set to None if nick_name (nullable) is None
        # and model_fields_set contains the field
        if self.nick_name is None and "nick_name" in self.model_fields_set:
            _dict['nickName'] = None

        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if user_name (nullable) is None
        # and model_fields_set contains the field
        if self.user_name is None and "user_name" in self.model_fields_set:
            _dict['userName'] = None

        # set to None if pwd (nullable) is None
        # and model_fields_set contains the field
        if self.pwd is None and "pwd" in self.model_fields_set:
            _dict['pwd'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if phone (nullable) is None
        # and model_fields_set contains the field
        if self.phone is None and "phone" in self.model_fields_set:
            _dict['phone'] = None

        # set to None if relation_chain (nullable) is None
        # and model_fields_set contains the field
        if self.relation_chain is None and "relation_chain" in self.model_fields_set:
            _dict['relationChain'] = None

        # set to None if interest_tags (nullable) is None
        # and model_fields_set contains the field
        if self.interest_tags is None and "interest_tags" in self.model_fields_set:
            _dict['interestTags'] = None

        # set to None if biography (nullable) is None
        # and model_fields_set contains the field
        if self.biography is None and "biography" in self.model_fields_set:
            _dict['biography'] = None

        # set to None if gender (nullable) is None
        # and model_fields_set contains the field
        if self.gender is None and "gender" in self.model_fields_set:
            _dict['gender'] = None

        # set to None if birthday (nullable) is None
        # and model_fields_set contains the field
        if self.birthday is None and "birthday" in self.model_fields_set:
            _dict['birthday'] = None

        # set to None if occupation (nullable) is None
        # and model_fields_set contains the field
        if self.occupation is None and "occupation" in self.model_fields_set:
            _dict['occupation'] = None

        # set to None if education (nullable) is None
        # and model_fields_set contains the field
        if self.education is None and "education" in self.model_fields_set:
            _dict['education'] = None

        # set to None if contact (nullable) is None
        # and model_fields_set contains the field
        if self.contact is None and "contact" in self.model_fields_set:
            _dict['contact'] = None

        # set to None if languages (nullable) is None
        # and model_fields_set contains the field
        if self.languages is None and "languages" in self.model_fields_set:
            _dict['languages'] = None

        # set to None if social_links (nullable) is None
        # and model_fields_set contains the field
        if self.social_links is None and "social_links" in self.model_fields_set:
            _dict['socialLinks'] = None

        # set to None if relationship_status (nullable) is None
        # and model_fields_set contains the field
        if self.relationship_status is None and "relationship_status" in self.model_fields_set:
            _dict['relationshipStatus'] = None

        # set to None if company (nullable) is None
        # and model_fields_set contains the field
        if self.company is None and "company" in self.model_fields_set:
            _dict['company'] = None

        # set to None if industry (nullable) is None
        # and model_fields_set contains the field
        if self.industry is None and "industry" in self.model_fields_set:
            _dict['industry'] = None

        # set to None if company_position (nullable) is None
        # and model_fields_set contains the field
        if self.company_position is None and "company_position" in self.model_fields_set:
            _dict['companyPosition'] = None

        # set to None if private_settings (nullable) is None
        # and model_fields_set contains the field
        if self.private_settings is None and "private_settings" in self.model_fields_set:
            _dict['privateSettings'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of User from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "platform": obj.get("platform"),
            "unionID": obj.get("unionID"),
            "nickName": obj.get("nickName"),
            "avatar": obj.get("avatar"),
            "data": obj.get("data"),
            "userName": obj.get("userName"),
            "pwd": obj.get("pwd"),
            "email": obj.get("email"),
            "emailIsValid": obj.get("emailIsValid"),
            "phone": obj.get("phone"),
            "phoneIsValid": obj.get("phoneIsValid"),
            "relationChain": obj.get("relationChain"),
            "interestTags": obj.get("interestTags"),
            "biography": obj.get("biography"),
            "gender": obj.get("gender"),
            "birthday": obj.get("birthday"),
            "occupation": obj.get("occupation"),
            "education": obj.get("education"),
            "contact": obj.get("contact"),
            "languages": obj.get("languages"),
            "socialLinks": obj.get("socialLinks"),
            "relationshipStatus": obj.get("relationshipStatus"),
            "company": obj.get("company"),
            "industry": obj.get("industry"),
            "companyPosition": obj.get("companyPosition"),
            "privateSettings": obj.get("privateSettings"),
            "isLock": obj.get("isLock"),
            "lockUntil": obj.get("lockUntil"),
            "enableUserNameSignIn": obj.get("enableUserNameSignIn"),
            "enableEmailSignIn": obj.get("enableEmailSignIn"),
            "enablePhoneSignIn": obj.get("enablePhoneSignIn"),
            "enableUnionIDSignIn": obj.get("enableUnionIDSignIn"),
            "enableOAuth": obj.get("enableOAuth"),
            "enable2FAAuth": obj.get("enable2FAAuth"),
            "createDate": obj.get("createDate"),
            "lastUpdate": obj.get("lastUpdate")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.0.0"

# import apis into sdk package
from ZSGF.Client.api.access_token_api import AccessTokenApi
from ZSGF.Client.api.alipay_api import AlipayApi
from ZSGF.Client.api.app_api import AppApi
from ZSGF.Client.api.ding_talk_api import DingTalkApi
from ZSGF.Client.api.external_account_api import ExternalAccountApi
from ZSGF.Client.api.file_api import FileApi
from ZSGF.Client.api.o_auth_api import OAuthApi
from ZSGF.Client.api.order_api import OrderApi
from ZSGF.Client.api.storage_api import StorageApi
from ZSGF.Client.api.user_api import UserApi
from ZSGF.Client.api.user_currency_api import UserCurrencyApi
from ZSGF.Client.api.user_friends_api import UserFriendsApi
from ZSGF.Client.api.user_location_api import UserLocationApi
from ZSGF.Client.api.wechat_api import WechatApi

# import ApiClient
from ZSGF.Client.api_response import ApiResponse
from ZSGF.Client.api_client import ApiClient
from ZSGF.Client.configuration import Configuration
from ZSGF.Client.exceptions import OpenApiException
from ZSGF.Client.exceptions import ApiTypeError
from ZSGF.Client.exceptions import ApiValueError
from ZSGF.Client.exceptions import ApiKeyError
from ZSGF.Client.exceptions import ApiAttributeError
from ZSGF.Client.exceptions import ApiException

# import models into sdk package
from ZSGF.Client.models.access_token_list_result import AccessTokenListResult
from ZSGF.Client.models.access_token_list_result_api_response import AccessTokenListResultApiResponse
from ZSGF.Client.models.access_token_post_request import AccessTokenPostRequest
from ZSGF.Client.models.access_token_put_request import AccessTokenPutRequest
from ZSGF.Client.models.alipay_create_order_page_pay_request import AlipayCreateOrderPagePayRequest
from ZSGF.Client.models.alipay_create_order_request import AlipayCreateOrderRequest
from ZSGF.Client.models.alipay_create_order_wap_pay_request import AlipayCreateOrderWapPayRequest
from ZSGF.Client.models.alipay_trade_query_response import AlipayTradeQueryResponse
from ZSGF.Client.models.alipay_trade_query_response_api_response import AlipayTradeQueryResponseApiResponse
from ZSGF.Client.models.alipay_trade_refund_response import AlipayTradeRefundResponse
from ZSGF.Client.models.alipay_trade_refund_response_api_response import AlipayTradeRefundResponseApiResponse
from ZSGF.Client.models.app_info_item import AppInfoItem
from ZSGF.Client.models.app_info_result import AppInfoResult
from ZSGF.Client.models.app_info_result_api_response import AppInfoResultApiResponse
from ZSGF.Client.models.app_property import AppProperty
from ZSGF.Client.models.app_user_consent_model import AppUserConsentModel
from ZSGF.Client.models.app_user_consent_model_list_api_response import AppUserConsentModelListApiResponse
from ZSGF.Client.models.app_user_reset_email_request import AppUserResetEmailRequest
from ZSGF.Client.models.app_user_reset_phone_request import AppUserResetPhoneRequest
from ZSGF.Client.models.app_user_reset_pwd_request import AppUserResetPwdRequest
from ZSGF.Client.models.authorize_result import AuthorizeResult
from ZSGF.Client.models.authorize_result_api_response import AuthorizeResultApiResponse
from ZSGF.Client.models.bk_agent_resp_info import BkAgentRespInfo
from ZSGF.Client.models.boolean_api_response import BooleanApiResponse
from ZSGF.Client.models.charge_info import ChargeInfo
from ZSGF.Client.models.common_friend_model import CommonFriendModel
from ZSGF.Client.models.contribute_detail import ContributeDetail
from ZSGF.Client.models.create_order_request import CreateOrderRequest
from ZSGF.Client.models.create_order_result import CreateOrderResult
from ZSGF.Client.models.create_order_result_api_response import CreateOrderResultApiResponse
from ZSGF.Client.models.currency_consume_request import CurrencyConsumeRequest
from ZSGF.Client.models.currency_transaction import CurrencyTransaction
from ZSGF.Client.models.directory_item import DirectoryItem
from ZSGF.Client.models.email_sign_in_request import EmailSignInRequest
from ZSGF.Client.models.email_sign_up_request import EmailSignUpRequest
from ZSGF.Client.models.enterprise_pay_info import EnterprisePayInfo
from ZSGF.Client.models.exchange_currency_request import ExchangeCurrencyRequest
from ZSGF.Client.models.external_account_bind_request import ExternalAccountBindRequest
from ZSGF.Client.models.external_account_put_request import ExternalAccountPutRequest
from ZSGF.Client.models.external_account_sign_in_request import ExternalAccountSignInRequest
from ZSGF.Client.models.file_item import FileItem
from ZSGF.Client.models.file_list_result import FileListResult
from ZSGF.Client.models.file_list_result_api_response import FileListResultApiResponse
from ZSGF.Client.models.follower_model import FollowerModel
from ZSGF.Client.models.follower_put_model import FollowerPutModel
from ZSGF.Client.models.fulfillment_detail import FulfillmentDetail
from ZSGF.Client.models.geo_location import GeoLocation
from ZSGF.Client.models.geo_location_model import GeoLocationModel
from ZSGF.Client.models.geo_location_model_api_response import GeoLocationModelApiResponse
from ZSGF.Client.models.geo_location_response_model import GeoLocationResponseModel
from ZSGF.Client.models.get_user_profile_result import GetUserProfileResult
from ZSGF.Client.models.get_user_profile_result_api_response import GetUserProfileResultApiResponse
from ZSGF.Client.models.goods_detail import GoodsDetail
from ZSGF.Client.models.grant_request import GrantRequest
from ZSGF.Client.models.grant_result import GrantResult
from ZSGF.Client.models.grant_result_api_response import GrantResultApiResponse
from ZSGF.Client.models.hb_fq_pay_info import HbFqPayInfo
from ZSGF.Client.models.int64_api_response import Int64ApiResponse
from ZSGF.Client.models.intact_charge_info import IntactChargeInfo
from ZSGF.Client.models.my_sql_geometry import MySqlGeometry
from ZSGF.Client.models.object_api_response import ObjectApiResponse
from ZSGF.Client.models.object_list_api_response import ObjectListApiResponse
from ZSGF.Client.models.order import Order
from ZSGF.Client.models.order_api_response import OrderApiResponse
from ZSGF.Client.models.order_list_result import OrderListResult
from ZSGF.Client.models.order_list_result_api_response import OrderListResultApiResponse
from ZSGF.Client.models.payment_info_with_id import PaymentInfoWithId
from ZSGF.Client.models.phone_sign_in_request import PhoneSignInRequest
from ZSGF.Client.models.phone_sign_up_request import PhoneSignUpRequest
from ZSGF.Client.models.preset_pay_tool_info import PresetPayToolInfo
from ZSGF.Client.models.profile_result import ProfileResult
from ZSGF.Client.models.profile_result_api_response import ProfileResultApiResponse
from ZSGF.Client.models.qr_code_pre_sign_in_request import QRCodePreSignInRequest
from ZSGF.Client.models.qr_code_scan_request import QRCodeScanRequest
from ZSGF.Client.models.qr_code_sign_in_request import QRCodeSignInRequest
from ZSGF.Client.models.qr_code_sign_up_request import QRCodeSignUpRequest
from ZSGF.Client.models.recharge_point_request import RechargePointRequest
from ZSGF.Client.models.recommend_friend import RecommendFriend
from ZSGF.Client.models.refund_charge_info import RefundChargeInfo
from ZSGF.Client.models.refund_sub_fee import RefundSubFee
from ZSGF.Client.models.return_page_notify_request import ReturnPageNotifyRequest
from ZSGF.Client.models.send_email_code_request import SendEmailCodeRequest
from ZSGF.Client.models.send_sms_code_request import SendSMSCodeRequest
from ZSGF.Client.models.setup_code import SetupCode
from ZSGF.Client.models.setup_code_api_response import SetupCodeApiResponse
from ZSGF.Client.models.sign_in_request import SignInRequest
from ZSGF.Client.models.sign_up_request import SignUpRequest
from ZSGF.Client.models.storage_list_result import StorageListResult
from ZSGF.Client.models.storage_list_result_api_response import StorageListResultApiResponse
from ZSGF.Client.models.string_api_response import StringApiResponse
from ZSGF.Client.models.sub_fee import SubFee
from ZSGF.Client.models.tap_pay_info import TapPayInfo
from ZSGF.Client.models.token_model import TokenModel
from ZSGF.Client.models.token_model_api_response import TokenModelApiResponse
from ZSGF.Client.models.trade_fund_bill import TradeFundBill
from ZSGF.Client.models.trade_settle_detail import TradeSettleDetail
from ZSGF.Client.models.trade_settle_info import TradeSettleInfo
from ZSGF.Client.models.union_id_sign_in_request import UnionIDSignInRequest
from ZSGF.Client.models.union_id_sign_up_request import UnionIDSignUpRequest
from ZSGF.Client.models.update_profile_request import UpdateProfileRequest
from ZSGF.Client.models.user import User
from ZSGF.Client.models.user_access_token import UserAccessToken
from ZSGF.Client.models.user_common_interests_result import UserCommonInterestsResult
from ZSGF.Client.models.user_common_interests_result_api_response import UserCommonInterestsResultApiResponse
from ZSGF.Client.models.user_currency import UserCurrency
from ZSGF.Client.models.user_currency_currency_trans_result import UserCurrencyCurrencyTransResult
from ZSGF.Client.models.user_currency_currency_trans_result_api_response import UserCurrencyCurrencyTransResultApiResponse
from ZSGF.Client.models.user_currency_list_api_response import UserCurrencyListApiResponse
from ZSGF.Client.models.user_followers_result import UserFollowersResult
from ZSGF.Client.models.user_followers_result_api_response import UserFollowersResultApiResponse
from ZSGF.Client.models.user_friends_near_by_result import UserFriendsNearByResult
from ZSGF.Client.models.user_friends_near_by_result_api_response import UserFriendsNearByResultApiResponse
from ZSGF.Client.models.user_location_post_result import UserLocationPostResult
from ZSGF.Client.models.user_location_post_result_api_response import UserLocationPostResultApiResponse
from ZSGF.Client.models.user_locations_result import UserLocationsResult
from ZSGF.Client.models.user_locations_result_api_response import UserLocationsResultApiResponse
from ZSGF.Client.models.user_logins import UserLogins
from ZSGF.Client.models.user_logins_list_api_response import UserLoginsListApiResponse
from ZSGF.Client.models.user_mutual_followers_result import UserMutualFollowersResult
from ZSGF.Client.models.user_mutual_followers_result_api_response import UserMutualFollowersResultApiResponse
from ZSGF.Client.models.user_mutual_followings_result import UserMutualFollowingsResult
from ZSGF.Client.models.user_mutual_followings_result_api_response import UserMutualFollowingsResultApiResponse
from ZSGF.Client.models.user_profile_result import UserProfileResult
from ZSGF.Client.models.user_profile_result_api_response import UserProfileResultApiResponse
from ZSGF.Client.models.user_qr_code_scan_result import UserQRCodeScanResult
from ZSGF.Client.models.user_qr_code_scan_result_api_response import UserQRCodeScanResultApiResponse
from ZSGF.Client.models.voucher_detail import VoucherDetail
from ZSGF.Client.models.wechat_js_config_result import WechatJSConfigResult
from ZSGF.Client.models.wechat_js_config_result_api_response import WechatJSConfigResultApiResponse
